# OctoBot-Tentacles-Manager [2.0.4](https://github.com/Drakkar-Software/OctoBot-Tentacles-Manager/tree/master/CHANGELOG.md)
[![PyPI](https://img.shields.io/pypi/v/OctoBot-Tentacles-Manager.svg)](https://pypi.python.org/pypi/OctoBot-Tentacles-Manager/)
[![Downloads](https://pepy.tech/badge/OctoBot-Tentacles-Manager/month)](https://pepy.tech/project/OctoBot-Tentacles-Manager)
[![Build Status](https://travis-ci.com/Drakkar-Software/OctoBot-Tentacles-Manager.svg?branch=master)](https://travis-ci.com/Drakkar-Software/OctoBot-Tentacles-Manager)
[![Build status](https://ci.appveyor.com/api/projects/status/c7afc4o5bxt84po9?svg=true)](https://ci.appveyor.com/project/Herklos/octobot-tentacles-manager)


A module manager for your [OctoBot](https://github.com/Drakkar-Software/OctoBot) ! 

- Install OctoBot-Tentacles-Manager from pip : 

``` {.sourceCode .bash}
$ python3 -m pip install OctoBot-Tentacles-Manager
```

## Usage
- Install [OctoBot](https://github.com/Drakkar-Software/OctoBot)

- Use the integrated CLI interface: 

``` {.sourceCode .bash}
$ python3 octobot_tentacles_manager/cli.py --help
```

OR 

- Use CLI interface directly with OctoBot: 

Python:
``` {.sourceCode .bash}
$ python3 tentacles install all
```
Binary:
``` {.sourceCode .bash}
$ ./OctoBot tentacles install all
```

- Use your [OctoBot web interface at **'Tentacles'**.](https://github.com/Drakkar-Software/OctoBot/wiki/Customize-your-OctoBot#octobot-is-customizable-)

